# python-corona-api
An asynchronous wrapper for the [NovelCOVID API](https://github.com/NovelCOVID/API) written in Python.

This is designed for bots using [discord.py](https://github.com/Rapptz/discord.py) but there is no discord-specific code so you are free to use this in any project as required. 

# Requirements
 - Python 3.5 or above
 - aiohttp (`python3 -m pip install -U aiohttp`)

# Installation
### Using pip (recommended)
 - `python3 -m pip install -U corona_api`
 
# Support
Get support for this over on [Discord](https://takagisan.xyz/support).
 
# Examples
### Discord bot
There is an example cog for your Discord bot [here](https://github.com/apex2504/python-corona-api/blob/master/examples/discord_cog.py).
